@@ -1,9 +1,7 @@
-# -*- coding: utf-8 -*-
-
+__version__ = "0.0.4"
 __description__ = "Python client for interfacing with NTCore"
 __license__ = "Apache 2.0"
-__maintainer__ = "Jinxiong Tan"
-__maintainer_email__ = "jtan@nantutech.com"
+__maintainer__ = "NTCore"
+__maintainer_email__ = "info@nantutech.com"
 __title__ = "ntcore"
-__url__ = "https://www.nantu.io/"
-__version__ = "0.0.3"
\ No newline at end of file
+__url__ = "https://www.nantu.io/"
\ No newline at end of file
